										****
*****************Program's authors: Stefano Rosignoli and Luca Tiberti*****************
********Contact details: stefano.rosignoli@irpet.it; luca.tiberti@ecn.ulaval.ca**********
***Research study: Food and Financial Crises on child mortality in sub-Saharan Africa***
******************************Version December 2010******************************
										****

***Note: this do.file was construct to estimate the model in: 
***Cornia,G.A., S. Rosignoli and L. Tiberti (2011), "The Impact of the Food and Financial Crises on Child Mortality: The Case of sub-Saharan Africa?, Innocenti Working Paper No. 2011-01, UNICEF Innocenti Research Centre, Florence.
										
clear
set matsize 500
clear mata
set more off

**OPEN THE WHOLE DATASET
use "dbmodel1.dta",clear

**DEFINITION OF VARIABLES' LABELS
label var cod "three letter country code"
label var country "Country"
label var year "Year"
label var imr "Infant Mortality Rate (IMR)"
label var ufmr "Under 5 Mortality Rate (U5MR)"
label var birthrate "Birth rate, crude (per 1,000 people)"
label var birthratesk "Births attended by skilled health staff (% of total)"
label var co2pgdp "CO2 emissions (kg per 2005 PPP $ of GDP)"
label var co2tot "CO2 emissions (kt)"
label var co2pc "CO2 emissions (metric tons per capita)"
label var regbirth "Completeness of birth registration (%)"
label var regbirthrur "Completeness of birth registration, rural (%)"
label var regbirthurb "Completeness of birth registration, urban (%)"
label var conspidx "Consumer price index (2005 = 100)"
label var iodsalt "Consumption of iodized salt (% of households)"
label var croprodidx "Crop production index (1999-2001 = 100)"
label var cerealsprodidx "Cereals production index (1999-2001 = 100)"
label var kcalpc "Depth of hunger (kilocalories per person per day)"
label var diarrheatrat "Diarrhea treatment (% of children under 5 receiving oral rehydration and continued feeding)"
label var fertility "Fertility rate, total (births per woman)"
label var foodpridx "Food production index (1999-2001 = 100)"
label var foodexport "Food exports (% of merchandise exports)"
label var foodimport "Food imports (% of merchandise imports)"
label var gdppc "GDP per capita, PPP (constant 2005 international $)"
label var gdppcgrw "GDP per capita growth (annual %)"
label var gdp "GDP (constant 2000 US$)"
label var hexppc "Health expenditure per capita, PPP (constant 2005 international $)"
label var hexpprivate "Health expenditure, private (% of GDP)"
label var hexppublic "Health expenditure, public (% of GDP)"
label var thepgdp "Total expenditure on health (THE) as % of GDP"
label var extreshealt "External resources on health as % of THE"
label var aidhealth_oecd "Commitments (constant 2008 USD millions)-health"
label var gghepthe "General government expenditure on health (GGHE) as % of THE"
label var pvthe "Private expenditure on health (PvtHE) as % of THE"
label var gghepggexp "GGHE as % of General government expenditure"
label var ssecpgghe "Social security funds as % of GGHE"
label var pvtinsppvthe "Private insurance as % of PvtHE"
label var oopokppvthe "Out of pocket expenditure as % of PvtHE"
label var hospbedspc "Hospital beds (per 1,000 people)"
label var imdpt "Immunization, DPT (% of children ages 12-23 months)"
label var immeasles "Immunization, measles (% of children ages 12-23 months)"
label var sanittot "Improved sanitation facilities (% of population with access)"
label var sanitrur "Improved sanitation facilities, rural (% of rural population with access)"
label var saniturb "Improved sanitation facilities, urban (% of urban population with access)"
label var watertot "Improved water source (% of population with access)"
label var waterrur "Improved water source, rural (% of rural population with access)"
label var waterurb "Improved water source, urban (% of urban population with access)"
label var migrantpc "International migrant stock (% of population)"
label var migranttot "International migrant stock, total"
label var literfem15_2 "Literacy rate, adult female (% of females ages 15 and above)"
label var litertot15_2 "Literacy rate, adult total (% of people ages 15 and above)"
label var literfem1524 "Literacy rate, youth female (% of females ages 15-24)"
label var litertot1524 "Literacy rate, youth total (% of people ages 15-24)"
label var pricompfem "percentage of population (15+), 15+, female, completed primary da barro and lee"
label var seccompfem "percentage of population (15+), 15+, female, completed secondary da barro and lee"
label var pricomptot "percentage of population (15+), 15+, total, completed primary da barro and lee"
label var seccompltot "percentage of population (15+), 15+, total, completed secondary da barro and lee"
label var literfem15 "Literacy  female 15+da barro and lee"
label var litertot15 "Literacy  total 15+da barro and lee"
label var literfem1544 "proportion, 15-44, female, literacy da barro and lee"
label var litertot1544 "proportion, 15-44, total, literacy da barro and lee"
label var prifem1544 "proportion, 15-44, female, primary da barro and lee"
label var pritot1544 "proportion, 15-44, total, primary da barro and lee"
label var secfem1544 "proportion, 15-44, female, secondary da barro and lee"
label var sectot1544 "proportion, 15-44, total, secondary da barro and lee"
label var heightforage "Malnutrition prevalence, height for age (% of children under 5)"
label var weightforage "Malnutrition prevalence, weight for age (% of children under 5)"
label var wastingpc "Prevalence of wasting (% of children under 5)"
label var undernoursh "Prevalence of undernourishment (% of population)"
label var lowbirthw "Low-birthweight babies (% of births)"
label var nurses "Nurses and midwives (per 1,000 people)"
label var physicians "Physicians (per 1,000 people)"
label var popu14 "Population ages 0-14 (% of total)"
label var ruralpop "Rural population (% of total population)"
label var tubercincid "Incidence of tuberculosis (per 100,000 people)"
label var tubercdetect "Tuberculosis case detection rate (all forms)"
label var tuberctreat "Tuberculosis treatment success rate (% of registered cases)"
label var tubercprev "Tuberculosis prevalence rate (per 100,000 population, WHO)"
label var urbanpop "Urban population (% of total)"
label var insectbednet "Use of insecticide-treated bed nets (% of under-5 population)"
label var vitaminrate "Vitamin A supplementation coverage rate (% of children ages 6-59 months)"
label var prenatalcare "Pregnant women receiving prenatal care (%)"
label var pidxmaize "Maize (producer price, US$/tonne)"
label var pidxmillet "Millet (producer price, US$/tonne)"
label var pidxrice "Rice, paddy (producer price, US$/tonne)"
label var pidxsorghum "Sorghum (producer price, US$/tonne)"
label var gini "GINI"
label var cshare1 "consumption_share_1"
label var cshare2 "consumption_share_2"
label var cshare3 "consumption_share_3"
label var cshare4 "consumption_share_4"
label var cshare5 "consumption_share_5"
label var cshare6 "consumption_share_6"
label var cshare7 "consumption_share_7"
label var cshare8 "consumption_share_8"
label var cshare9 "consumption_share_9"
label var cshare10 "consumption_share_10"
label var latitude "latitude"
label var longitude "longitude"
label var agedeprat "Age dependency ratio (dependents to working-age population)"
label var cerexpq "Cereal exports quantity (FAO, tonnes)"
label var cerimpq "Cereal imports quantity (FAO, tonnes)"
label var cerfoodaid "Cereal food aid shipments (FAO, tonnes)"
label var antimalarial "Children under five with fever treated with any antimalarial drugs (%)"
label var corruption "Corruption Perceptions Index (score)"
label var malariadeaths "Deaths among children under five years of age due to malaria (%)"
label var odahealth "Gross ODA aid disbursement for health, DAC donors total (current US$)"
label var hconspc "Household final consumption expenditure per capita (constant 2000 US$)"
label var hconspcgr "Household final consumption expenditure per capita growth (annual %)"
label var hcons "Household final consumption expenditure, PPP (constant 2005 international $)"
label var radiorate "Households with a radio (%)"
label var foodimportq "Import volume index, food"
label var income4q "Income share held by fourth 20%"
label var income5q "Income share held by highest 20%"
label var income1q "Income share held by lowest 20%"
label var income3q "Income share held by third 20%"
label var income2q "Income share held by second 20%"
label var malmortrate "Malaria mortality (annual, per 100,000 population)"
label var matmortrate "Maternal mortality ratio, national estimate (per 100,000 live births)"
label var solidfuels "Population using solid fuels, total (% of population)"
label var radioset "Radio sets (per 1,000 people)"
label var breastfeed "Exclusive breastfeeding (% of children under 6 months)"
label var antitetanusneon "Neonates protected at birth against neonatal tetanus (PAB) (%)"
label var hivchild "People living with HIV/AIDS, children 0-14 years"
label var hivpregnant "HIV positive pregnant women receiving antiretrovirals, using WHO/UNAIDS methodology (%)"
label var hivpc "Prevalence of HIV, total (% of population ages 15-49) - 2010 estimates"
label var popfem04 "Population ages 0-4, female (% of female population)"
label var popmal04 "Population ages 0-4, male (% of male population)"
label var poptot "Population, total"
label var popfem "Population, female"
label var popmal "Population, male"
label var malariacases "Reported malaria cases WHO"
label var maldeathswho "Reported malaria deaths WHO"
label var conflicts "conflicts by intensity degree"
label var agricnetprod "Net Production 1999-2001 (1000 I$), agriculture"
label var odatot "Official development assistance and official aid (constant 2007 US$)"
label var tot_c1 "Antenatal Care - Doctor  % on relevant pop"
label var tot_c2 "Antenatal care - Other health professional % on relevant pop"
label var tot_e1 "Birth Delivery - Health facility %"
label var tot_f1 "Assistance during delivery - Doctor %"
label var tot_f2 "Assistance during delivery - Other health professional %"
label var tot_h3 "Percentage of children with ARI taken to a health facility "
label var tot_j2 "ORS packet %"
label var tot_k2 "Exclusive breastfeeding %"
label var tot_l2 "Height-for-age below -2 SD %"
label var gdppcicu "GDP per capita, PPP (current international $)"
label var gdppclku "GDP per capita (constant LCU)"
label var gdplcu "GDP (current LCU)"
label var demindex "Institutionalized democracy"
label var gdpdeflator "GDP deflator (base year varies by country)"
label var totpop0_4 "Population ages 0-4, total"
label var fempop15_44 "Population ages 15-44, female"
label var totpop15_49 "Population ages 15-49, total"
label var cerealshare "cereal share of total calorie intake (2009)"
label var foodimport_value "Food imports excluding fish (FAO, current US$)"
label var foodexport_value "Food exports excluding fish (FAO, current US$)"
label var cerealimport_value "Cereal imports (FAO, current US$)"
label var cerealexport_value "Cereal exports (FAO, current US$)"
label var gdppccu "GDP per capita (current US$)"
label var cereals_prod "Cereals (production, tonnes)"
label var pulses_prod "Pulses (production, tonnes)"
label var roots_prod "Roots and Tubers (production, tonnes)"
label var veg_prod "Vegetables&Melons (production, tonnes)"
label var pulses_import "Pulses (Imports)"
label var roots_import "Roots and Tubers (Imports)"
label var pulses_export "Pulses (Exports)"
label var roots_export "Roots and Tubers (Exports)"


** KEEP THE RELEVANT VARIABLES FOR THE MODEL
keep  cod country year imr ufmr birthrate gdppc thepgdp pvthe imdpt ///
immeasles sanittot watertot literfem1544 cerimpq hivpc popfem04 popmal04 ///
poptot conflicts extreshealt demindex  cereals_prod pulses_prod roots_prod ///
veg_prod pulses_import roots_import fpi cpi


** POINT TO POINT IMPUTATION FOR VARIABLES WITH A REGULAR TREND
foreach var of varlist imr ufmr birthrate sanittot watertot  literfem1544 /// 
immeasles imdpt extreshealt ///
{
bysort cod: ipolate `var' year,generate(xb)
replace `var'=xb
drop xb
}


***INTRODUCE SOME OTHER MINOR ADDITIONAL CHANGES FOLLOWING THE TREND IN THE PREVIOUS YEARS
replace	hivpc=	0.04	            if cod=="CPV"
replace	gdppc=	178.185     	if cod=="ZWE"& year==	2006
replace	gdppc=	171.796     	if cod=="ZWE"& year==	2007

replace	cerimpq=	638805      	if cod=="AGO"& year==	2008
replace	cerimpq=	894858      	if cod=="GHA"& year==	2008
replace	cerimpq=	1405930		if cod=="KEN"& year==	2008
replace	cerimpq=	28362	      	if cod=="LSO"& year==	2008
replace	cerimpq=	346550		if cod=="MDG"& year==	2008
replace	cerimpq=	810873		if cod=="MOZ"& year==	2008
replace	cerimpq=	3516340		if cod=="NGA"& year==	2008
replace	cerimpq=	116857		if cod=="RWA"& year==	2008
replace	cerimpq=	1600000		if cod=="SEN"& year==	2008

replace	literfem1544=	0.9170	if cod=="KEN"& year==	2006
replace	literfem1544=	0.9223	if cod=="KEN"& year==	2007
replace	literfem1544=	0.9276	if cod=="KEN"& year==	2008
replace	literfem1544=	0.1997	if cod=="NER"& year==	2006
replace	literfem1544=	1      	if cod=="SWZ"& year==	1995
replace	literfem1544=	1	      if cod=="SWZ"& year==	1996
replace	literfem1544=	1     	if cod=="SWZ"& year==	1997
replace	literfem1544=	1     	if cod=="SWZ"& year==	1998
replace	literfem1544=	1     	if cod=="SWZ"& year==	1999



***IDENTIFY THE LATEST OBSERVED YEAR FOR EACH COUNTRY (ACCORDING TO THE YEAR OF THE LATEST AVAILABLE SURVEY'S USED FOR THE ESTIMATION OF IMR AND U5MR BY THE IGCME)
***THIS YEAR REPRESENTS THE LAST YEAR ENTERING IN THE REGRESSION ANALYSIS
gen dummy_time=0
replace dummy_time=1 if cod=="AGO" & year<=2008
replace dummy_time=1 if cod=="BEN" & year<=2006
replace dummy_time=1 if cod=="BWA" & year<=2007
replace dummy_time=1 if cod=="BFA" & year<=2006
replace dummy_time=1 if cod=="BDI" & year<=2005
replace dummy_time=1 if cod=="CMR" & year<=2004
replace dummy_time=1 if cod=="CPV" & year<=2005
replace dummy_time=1 if cod=="CAF" & year<=2006
replace dummy_time=1 if cod=="TCD" & year<=2004
replace dummy_time=1 if cod=="COG" & year<=2005
replace dummy_time=1 if cod=="ZAR" & year<=2007
replace dummy_time=1 if cod=="CIV" & year<=2005
replace dummy_time=1 if cod=="GNQ" & year<=2001
replace dummy_time=1 if cod=="ERI" & year<=2002
replace dummy_time=1 if cod=="ETH" & year<=2005
replace dummy_time=1 if cod=="GAB" & year<=2001
replace dummy_time=1 if cod=="GMB" & year<=2006
replace dummy_time=1 if cod=="GHA" & year<=2008
replace dummy_time=1 if cod=="GIN" & year<=2005
replace dummy_time=1 if cod=="GNB" & year<=2006
replace dummy_time=1 if cod=="KEN" & year<=2008
replace dummy_time=1 if cod=="LSO" & year<=2009
replace dummy_time=1 if cod=="LBR" & year<=2009
replace dummy_time=1 if cod=="MDG" & year<=2008
replace dummy_time=1 if cod=="MWI" & year<=2006
replace dummy_time=1 if cod=="MLI" & year<=2006
replace dummy_time=1 if cod=="MRT" & year<=2007
replace dummy_time=1 if cod=="MOZ" & year<=2008
replace dummy_time=1 if cod=="NAM" & year<=2006
replace dummy_time=1 if cod=="NER" & year<=2006
replace dummy_time=1 if cod=="NGA" & year<=2008
replace dummy_time=1 if cod=="RWA" & year<=2008
replace dummy_time=1 if cod=="STP" & year<=2008
replace dummy_time=1 if cod=="SEN" & year<=2008
replace dummy_time=1 if cod=="SLE" & year<=2005
replace dummy_time=1 if cod=="SOM" & year<=1999
replace dummy_time=1 if cod=="ZAF" & year<=2007
replace dummy_time=1 if cod=="SDN" & year<=2006
replace dummy_time=1 if cod=="SWZ" & year<=2006
replace dummy_time=1 if cod=="TZA" & year<=2007
replace dummy_time=1 if cod=="TGO" & year<=2006
replace dummy_time=1 if cod=="UGA" & year<=2006
replace dummy_time=1 if cod=="ZMB" & year<=2007
replace dummy_time=1 if cod=="ZWE" & year<=2009


** GENERATE OF MODEL'S VARIABLES

gen lnufsr=ln((1000-ufmr)/ufmr)         //ufsr=under five survival rate - we take the logit value [logit(ufsr)=ln((1000-ufmr)/ufmr)=ln(ufsr)-ln(ufmr)*/

gen lngdppc=ln(gdppc)  
egen water_sanit=rmean(watertot sanittot)

gen foodprice_rate=ln(fpi/cpi)

gen pvthepgdp=pvthe*thepgdp/100
gen gvthepgdp=thepgdp-pvthepgdp
 
replace conflicts=1-(conflicts==.)
egen immuniz_tot=rmean(imdpt immeasles)
gen lnextaidhealth=ln(extreshealt*thepgdp*gdppc/10000)

gen cereals_prodpc=(cereals_prod/poptot)
gen pulses_prodpc=(pulses_prod/poptot)
gen roots_prodpc=(roots_prod/poptot)
gen veg_prodpc=(veg_prod/poptot)
replace cerimpq=cerimpq/poptot
replace pulses_import=pulses_import/poptot
replace roots_import=roots_import/poptot

gen majorfoodpr=cereals_prodpc+pulses_prodpc+roots_prodpc+veg_prodpc
gen majorfoodimp=cerimpq+pulses_import+roots_import
gen totmajorfood=majorfoodpr+majorfoodimp
gen imp_tot_ratio=majorfoodimp/totmajorfood
gen under5pop=(popfem04*popfem+popmal04*popmal)/100
gen under1pop=(birthrate*poptot)/1000*(1-imr/1000)

** SET PANEL STRUCTURE
egen panel=group(country)
xtset panel year

**** ANOVA FOR U5MR
anova ufmr year
anova ufmr panel
anova ufmr year panel

*** MODEL - WE EXCLUDED ZIMBABWE**********************************************
xi: xtreg lnufsr lngdppc  water_sanit hivpc foodprice_rate gvthepgdp totmajorfood lnextaidhealth literfem1544 imp_tot_ratio immuniz_tot demindex conflicts if dummy_time==1&year<2008&cod!="ZWE", fe
predict fixed_ufsr,u
estimates store reg1

**OMITTED VARIABLE TEST *****************************************
xi: reg lnufsr lngdppc  water_sanit hivpc foodprice_rate gvthepgdp totmajorfood imp_tot_ratio lnextaidhealth literfem1544 immuniz_tot demindex conflicts i.cod if dummy_time==1&year<2008&cod!="ZWE"
ovtest

**SPECIFICATION TEST*****************************************
xi: xtreg lnufsr lngdppc water_sanit hivpc foodprice_rate gvthepgdp totmajorfood imp_tot_ratio lnextaidhealth literfem1544 imdpt immeasles immuniz_tot demindex i.conflicts if dummy_time==1&year<2008, fe
estimates store fixed
xi: xtreg lnufsr lngdppc water_sanit hivpc foodprice_rate gvthepgdp totmajorfood imp_tot_ratio lnextaidhealth literfem1544 imdpt immeasles immuniz_tot demindex i.conflicts if dummy_time==1&year<2008, re
hausman fixed .

**CORRELATION MATRIX*****************************************
corr lnufsr lngdppc  water_sanit hivpc foodprice_rate gvthepgdp totmajorfood lnextaidhealth literfem1544 imp_tot_ratio  immuniz_tot demindex conflicts if dummy_time==1&year<2008&cod!="ZWE"
